import { Component, OnInit } from '@angular/core';
import { Empleado } from 'app/models/empleado';
import { Proveedor } from 'app/models/proveedor';
import { Contrato } from 'app/models/contrato';
import { Router } from '@angular/router';
import { FormBuilder } from '@angular/forms';
import { ContratoService } from 'app/services/contrato.service';
import { ProveedorService } from 'app/services/proveedor.service';
import { TipoContrato } from 'app/models/tipo-contrato';
import { TipoContratoService } from 'app/services/tipo-contrato.service';
import { EmpleadoService } from 'app/services/empleado.service';

@Component({
  selector: 'app-contrato-add',
  templateUrl: './contrato-add.component.html',
  styleUrls: ['./contrato-add.component.scss']
})

export class ContratoAddComponent implements OnInit {
  fpcontrato: TipoContrato[];
  proveedores: Proveedor[];
  admin: Empleado[];
  contrato: Contrato = new Contrato();
  submitted = false;
  constructor(
    private router: Router,
    private formBuilder: FormBuilder,
    private contratoService: ContratoService,
    private proveedorService: ProveedorService,
    private fpService: TipoContratoService,
    private emmpleadoService: EmpleadoService
  ) {}

  ngOnInit() {
    this.getProveedores();
    this.getTipoContrato();
    this.getEmpleado();

  }

  newContrato(): void {
    this.submitted = false;
    this.contrato = new Contrato();
  }

  save() {
    this.contratoService.createContrato(this.contrato)
      .subscribe();
    this.contrato = new Contrato();
    this.gotoList();
  }

  onSubmit() {
    this.submitted = true;
    this.save();
  }

  gotoList() {
    this.router.navigate(['list-contrato']);
  }

  getProveedores() {
    this.proveedorService.getProveedoresList().subscribe((data: Proveedor[]) => {
      this.proveedores = data;
    }, (error) => {
      alert('A ocurrido un error al obtener proveedores');
    });
  }
  getTipoContrato() {
    this.fpService.getTiposList().subscribe((data: TipoContrato[]) => {
      this.fpcontrato = data;
    }, (error) => {
      alert('A ocurrido un error al obtener las formas de pago');
    });
  }
  getEmpleado() {
    this.emmpleadoService.getEmpleadosList().subscribe((data: Empleado[]) => {
      this.admin = data;
    }, (error) => {
      alert('A ocurrido un error al obtener los administradores')
    });
  }
}
