import { Component, OnInit } from '@angular/core';
import { ActivatedRoute, Router } from '@angular/router';
import { FormBuilder } from '@angular/forms';
import { ContratoService } from 'app/services/contrato.service';
import { Contrato } from 'app/models/contrato';
import { ProveedorService } from 'app/services/proveedor.service';
import { Proveedor } from 'app/models/proveedor';
import { EmpleadoService } from 'app/services/empleado.service';
import { Empleado } from 'app/models/empleado';
import { TipoContratoService } from 'app/services/tipo-contrato.service';
import { TipoContrato } from 'app/models/tipo-contrato';

@Component({
  selector: 'app-contrato-edit',
  templateUrl: './contrato-edit.component.html',
  styleUrls: ['./contrato-edit.component.scss']
})
export class ContratoEditComponent implements OnInit {
  fpcontrato: TipoContrato[];
  proveedores: Proveedor[];
  admin: Empleado[];
  
id: number;
contrato: Contrato;
  constructor( private route: ActivatedRoute,
    private router: Router,
    private formBuilder: FormBuilder,
    private contratoService: ContratoService,
    private proveedorService: ProveedorService,
    private fpService: TipoContratoService,
    private emmpleadoService: EmpleadoService
      ) {
        
       }

  ngOnInit() {
    this.getProveedores();
    this.getTipoContrato();
    this.getEmpleado();

    this.contrato = new Contrato();
    this.id = this.route.snapshot.params['id'];
    this.contratoService.getContrato(this.id)
      .subscribe(data => {
        console.log(data)
        this.contrato = data;
      }, error => console.log(error));
  }
  
  update() {
    this.contratoService.updateContrato(this.id, this.contrato)
      .subscribe(data => console.log(data), error => console.log(error));
    this.contrato = new Contrato();
    this.router.navigate(['list-contrato']);
  }

  getProveedores() {
    this.proveedorService.getProveedoresList().subscribe((data: Proveedor[]) => {
      this.proveedores = data;
    }, (error) => {
      alert('A ocurrido un error al obtener proveedores');
    });
  }
  getTipoContrato() {
    this.fpService.getTiposList().subscribe((data: TipoContrato[]) => {
      this.fpcontrato = data;
    }, (error) => {
      alert('A ocurrido un error al obtener las formas de pago');
    });
  }
  getEmpleado() {
    this.emmpleadoService.getEmpleadosList().subscribe((data: Empleado[]) => {
      this.admin = data;
    }, (error) => {
      alert('A ocurrido un error al obtener los administradores')
    });
  }
}
