import { Component, OnInit } from '@angular/core';
import { Router, ActivatedRoute } from '@angular/router';
import { FormBuilder } from '@angular/forms';
import { OrdenService } from 'app/services/orden.service';
import { Orden } from 'app/models/orden';
import { Certificado } from 'app/models/certificado';
import { CertificadoService } from 'app/services/certificado.service';
import { EmpleadoService } from 'app/services/empleado.service';
import { Empleado } from 'app/models/empleado';
@Component({
  selector: 'app-orden-add',
  templateUrl: './orden-add.component.html',
  styleUrls: ['./orden-add.component.scss']
})
export class OrdenAddComponent implements OnInit {
  id: number;
  certificado: Certificado;
  anio = new Date();
  ordenGasto: Orden = new Orden();
  submitted = false;
  G_BTN = true;
  S_BTN: boolean = true;
  show_campo: boolean = true;
  show_mes: boolean = true;
  show_dias: boolean = true;

  admin: Empleado[];

  constructor(
    private route: ActivatedRoute,
    private emmpleadoService: EmpleadoService,
    private router: Router,
    private formBuilder: FormBuilder,
    private ordenService: OrdenService,
    private certiService: CertificadoService
  ) {
  }
  ngOnInit() {
    this.inicio();
    this.id = this.route.snapshot.params['id'];
    this.findCertificado();
    this.getEmpleado();
    
  }
  inicio(){
    this.ordenGasto.ord_otro_impuesto=0;
    this.ordenGasto.ord_iva=0;
    this.ordenGasto.ord_instalacion=0;
  }
  getEmpleado() {
    this.emmpleadoService.getEmpleadosList().subscribe((data: Empleado[]) => {
      this.admin = data;
    }, (error) => {
      alert('A ocurrido un error al obtener los administradores')
    });
  }

  findCertificado() {
    this.certiService.getCertificado(this.id)
      .subscribe(data => {
        this.certificado = data;
        console.log(this.certificado);
      }, error => console.log(error));
  }

  

  onSubmit() {
   this.verificar_envio();
  }
  verificar_envio(){
    if (this.ordenGasto.ord_cantidad==null) {
      this.submitted = false;
    } else {
      this.submitted = true;
    this.save();
    }
  }
  gotoList() {
    this.router.navigate(['list-orden']);
  }
  ocultar() {
    this.G_BTN = true;
    this.S_BTN = true;
    this.show_campo = true;
    this.show_mes = true;
    this.show_dias = true;
  }
  // formulario mes
  FM() {
    this.S_BTN = !this.S_BTN;
    this.show_mes = !this.show_mes;
    this.show_campo = !this.show_campo;
  }
  // formulario dias
  FD() {
    
    this.S_BTN = !this.S_BTN;
    this.show_dias = !this.show_dias;
    this.show_mes = !this.show_mes;
    this.show_campo = !this.show_campo;
  }
  newOrdenGasto(): void {
    this.submitted = false;
    this.ordenGasto = new Orden();
  }

  verificar() {
    console.log("certificado saldo antiguo sub total " + this.certificado.cer_saldo_sub_to);
    console.log("certificado saldo antiguo iva " + this.certificado.cer_saldo_iva);
  }

  validaDIAS(){
    if (this.certificado.cer_saldo_sub_to == 0 || this.certificado.cer_saldo_iva == 0) {
      this.G_BTN = true;
      alert('Usted ya no tiene presupuesto para generar una orden de gasto \n' + "El valor actual del sub total es: " + this.certificado.cer_saldo_sub_to + "\n El valor actual del iva es: " + this.certificado.cer_saldo_iva);
    } else {
      this.FD();
      this.G_BTN = false;

    }
  }
  validaMES(){
    if (this.certificado.cer_saldo_sub_to == 0 || this.certificado.cer_saldo_iva == 0) {
      this.G_BTN = true;
      alert('Usted ya no tiene presupuesto para generar una orden de gasto \n' + "El valor actual del sub total es: " + this.certificado.cer_saldo_sub_to + "\n El valor actual del iva es: " + this.certificado.cer_saldo_iva);
    } else {
      this.FM();
      this.G_BTN = false;
    }
  }
  // pago 
  Pg() {
    this.ordenGasto.age = this.anio.getFullYear();
    this.ordenGasto.id_contrato = this.certificado.id_contrato;
    this.ordenGasto.ord_precio_unitario=(this.ordenGasto.ord_precio_unitario + this.ordenGasto.ord_instalacion);
    this.ordenGasto.ord_subtotal = (this.ordenGasto.ord_cantidad * this.ordenGasto.ord_precio_unitario);
    this.ordenGasto.ord_otro_impuesto = (this.ordenGasto.ord_subtotal) * (this.ordenGasto.ord_otro_impuesto / 100);
    this.ordenGasto.ord_iva = (this.ordenGasto.ord_subtotal + this.ordenGasto.ord_otro_impuesto) * (this.ordenGasto.ord_iva / 100);
    this.ordenGasto.ord_total = this.ordenGasto.ord_subtotal + this.ordenGasto.ord_otro_impuesto + this.ordenGasto.ord_iva ;
    this.ordenGasto.ord_gasto = this.ordenGasto.ord_subtotal + this.ordenGasto.ord_otro_impuesto;
    this.ordenGasto.ord_saldo_sub_to = (this.certificado.cer_saldo_sub_to - (this.ordenGasto.ord_subtotal + this.ordenGasto.ord_otro_impuesto));
    this.ordenGasto.ord_saldo_iva = (this.certificado.cer_saldo_iva - this.ordenGasto.ord_iva);
    
    
    this.certificado.cer_saldo_sub_to = this.ordenGasto.ord_saldo_sub_to;
    console.log("certificado saldo nuevo sub total " + this.certificado.cer_saldo_sub_to);
    this.certificado.cer_saldo_iva = this.ordenGasto.ord_saldo_iva;
    console.log("certificado saldo nuevo iva " + this.certificado.cer_saldo_iva);

  }
  
 

  savecerti() {
    this.certiService.updateCertifi(this.id, this.certificado)
      .subscribe(data => console.log(data), error => console.log(error));
    this.certificado = new Certificado();
    this.gotoList();
  }
  save() {
    this.verificar();
    this.Pg();
    this.savecerti();
    console.log(this.ordenGasto);
    this.ordenService.createOrdenGasto(this.ordenGasto)
      .subscribe();
    this.ordenGasto = new Orden();
    this.gotoList();
  }
}
